==> nextcloud-app-news-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/ro.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Solecitare nereușită, conexiune la rețeă indisponibilă!",
    "Request unauthorized. Are you logged in?" : "Cerere neautorizată. Ești autentificat ?",
    "Request forbidden. Are you an admin?" : "Cerere interzisă. Ești un administrator ?",
    "Token expired or app not enabled! Reload the page!" : "Token expirat sau aplicatie inactivă. Reîncarcă pagina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Eroare server internă! Controlați fișierul data/nextcloud.log pentru mai multe informații!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Solicitare nereușită, Nexcloud este momentan în mentenanță!",
    "Unread articles" : "Articole necitite",
    "News" : "Noutăți",
    "Saved" : "Salvat",
    "Download" : "Descarcă",
    "Close" : "Închide",
    "No articles available" : "Niciun articol disponibil",
    "No unread articles available" : "Niciun articol necitit disponibil",
    "Open website" : "Deschide website",
    "Keep article unread" : "Păstrează articolul necitit",
    "Username" : "Utilizator",
    "by" : "de",
    "from" : "de la",
    "Description" : "Descriere",
    "right" : "dreapta",
    "left" : "stânga",
    "Refresh" : "Împrospătare",
    "Subscribe" : "Abonare",
    "Web address" : "Adresă web",
    "Feed exists already!" : "Fluxul există deja!",
    "Folder" : "Director",
    "No folder" : "Niciun director",
    "New folder" : "Director nou",
    "Folder name" : "Denumire director",
    "Go back" : "Înapoi",
    "Folder exists already!" : "Directorul există deja!",
    "Credentials" : "Detalii de autentificare",
    "Password" : "Parolă",
    "New Folder" : "Director nou",
    "Create" : "Crează",
    "Explore" : "Explorează",
    "Update failed more than 50 times" : "Actualizarea a eșuat mai mult de 50 de ori",
    "Deleted feed" : "Flux șters",
    "Undo delete feed" : "Anulează ștergerea fluxului",
    "Rename" : "Redenumește",
    "Menu" : "Meniu",
    "Newest first" : "Cel mai nou mai întâi",
    "Oldest first" : "Cel mai vechi mai întâi",
    "Delete" : "Șterge",
    "Dismiss" : "Înlătură",
    "Collapse" : "Restrânge",
    "Deleted folder" : "Director șters",
    "Undo delete folder" : "Anulează ștergerea directorului",
    "Starred" : "Marcat",
    "All articles" : "Toate articolele",
    "Settings" : "Setări",
    "Compact view" : "Vizualizare compactă",
    "Show all articles" : "Arată toate articolele",
    "Subscriptions (OPML)" : "Subscripţii (OPLM)",
    "Import" : "Importă",
    "Export" : "Exportă",
    "Error when importing: file does not contain valid JSON" : "Eroare în timpul importării : fişierul nu conţine  JSON valid",
    "Help" : "Ajutor",
    "Keyboard shortcuts" : "Scurtături din tastatură",
    "Documentation" : "Documentație",
    "Report a bug" : "Raportează un defect"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-app-news-16.2.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/ro.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Solecitare nereușită, conexiune la rețeă indisponibilă!",
    "Request unauthorized. Are you logged in?" : "Cerere neautorizată. Ești autentificat ?",
    "Request forbidden. Are you an admin?" : "Cerere interzisă. Ești un administrator ?",
    "Token expired or app not enabled! Reload the page!" : "Token expirat sau aplicatie inactivă. Reîncarcă pagina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Eroare server internă! Controlați fișierul data/nextcloud.log pentru mai multe informații!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Solicitare nereușită, Nexcloud este momentan în mentenanță!",
    "News feeds" : "Fluxuri de știri",
    "Unread articles" : "Articole necitite",
    "News" : "Noutăți",
    "News folders" : "Fluxuri de știri",
    "Shared with me" : "Partajat cu mine",
    "An RSS/Atom feed reader" : "Un cititor de fluxuri RSS/Atom",
    "Use system cron for updates" : "Folosește programul cron pentru updates",
    "Disable this if you use a custom updater." : "Dezactivează această funcție dacă folosești un program diferit de actualizări.",
    "Purge interval" : "Interval de ștergere",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Număr minim de secunde ce trebuie să treacă pentru ca fluxurile și dosarele ștere să fie îndepărtate din baza de date; valorile sub 60 de secunde sunt ignorate.",
    "Maximum read count per feed" : "Număr maxim de citiri pentru un flux",
    "Maximum redirects" : "Numărul maxim de redirectări",
    "How many redirects the feed fetcher should follow." : "Cât de multe redirecționări ar trebui aplicația să urmărească.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Numărul maxim de secunde de așteptare pentru fuxurile RSS sau Atom; dacă ține mai mult timp atunci actualizarea va fi oprită.",
    "Explore Service URL" : "Explorează serviciul URL",
    "For more information check the wiki." : "Pentru mai multe informații verificați pagina wiki.",
    "Update interval" : "Interval de actualizări",
    "Saved" : "Salvat",
    "Download" : "Descarcă",
    "Close" : "Închide",
    "Subscribe to" : "Abonamează-te la",
    "No articles available" : "Niciun articol disponibil",
    "No unread articles available" : "Niciun articol necitit disponibil",
    "Open website" : "Deschide website",
    "Keep article unread" : "Păstrează articolul necitit",
    "Share" : "Partajează",
    "Username" : "Utilizator",
    "by" : "de",
    "from" : "de la",
    "Description" : "Descriere",
    "right" : "dreapta",
    "left" : "stânga",
    "Refresh" : "Împrospătare",
    "Subscribe" : "Abonare",
    "Web address" : "Adresă web",
    "Feed exists already!" : "Fluxul există deja!",
    "Folder" : "Director",
    "No folder" : "Niciun director",
    "New folder" : "Director nou",
    "Folder name" : "Denumire director",
    "Go back" : "Înapoi",
    "Folder exists already!" : "Directorul există deja!",
    "Credentials" : "Detalii de autentificare",
    "Password" : "Parolă",
    "New Folder" : "Director nou",
    "Create" : "Crează",
    "Explore" : "Explorează",
    "Update failed more than 50 times" : "Actualizarea a eșuat mai mult de 50 de ori",
    "Deleted feed" : "Flux șters",
    "Undo delete feed" : "Anulează ștergerea fluxului",
    "Rename" : "Redenumește",
    "Menu" : "Meniu",
    "Newest first" : "Cel mai nou mai întâi",
    "Oldest first" : "Cel mai vechi mai întâi",
    "Delete" : "Șterge",
    "Dismiss" : "Înlătură",
    "Collapse" : "Restrânge",
    "Deleted folder" : "Director șters",
    "Undo delete folder" : "Anulează ștergerea directorului",
    "Starred" : "Marcat",
    "All articles" : "Toate articolele",
    "Settings" : "Setări",
    "Compact view" : "Vizualizare compactă",
    "Show all articles" : "Arată toate articolele",
    "Subscriptions (OPML)" : "Subscripţii (OPLM)",
    "Import" : "Importă",
    "Export" : "Exportă",
    "Error when importing: file does not contain valid JSON" : "Eroare în timpul importării : fişierul nu conţine  JSON valid",
    "Help" : "Ajutor",
    "Keyboard shortcuts" : "Scurtături din tastatură",
    "Documentation" : "Documentație",
    "Report a bug" : "Raportează un defect"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
